summaryrefslogtreecommitdiffstats
path: root/net/test/python_utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/test/python_utils.h')
-rw-r--r--net/test/python_utils.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/net/test/python_utils.h b/net/test/python_utils.h
index c7cf289..583fb27 100644
--- a/net/test/python_utils.h
+++ b/net/test/python_utils.h
@@ -7,7 +7,6 @@
#include "base/compiler_specific.h"
-class CommandLine;
class FilePath;
// This is the python path variable name.
@@ -19,7 +18,7 @@ void AppendToPythonPath(const FilePath& dir);
// Return the location of the compiler-generated python protobuf.
bool GetPyProtoPath(FilePath* dir);
-// Returns the command that should be used to launch Python.
-bool GetPythonCommand(CommandLine* python_cmd) WARN_UNUSED_RESULT;
+// Returns the path that should be used to launch Python.
+bool GetPythonRunTime(FilePath* path) WARN_UNUSED_RESULT;
#endif // NET_TEST_PYTHON_UTILS_H_